summaryrefslogtreecommitdiffstats
path: root/kexi/kexidb/lookupfieldschema.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/kexidb/lookupfieldschema.h')
-rw-r--r--kexi/kexidb/lookupfieldschema.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/kexi/kexidb/lookupfieldschema.h b/kexi/kexidb/lookupfieldschema.h
index 9494b348..35d3b59f 100644
--- a/kexi/kexidb/lookupfieldschema.h
+++ b/kexi/kexidb/lookupfieldschema.h
@@ -20,12 +20,12 @@
#ifndef KEXIDB_LOOKUPFIELDSCHEMA_H
#define KEXIDB_LOOKUPFIELDSCHEMA_H
-#include <qvaluelist.h>
-#include <qstringlist.h>
+#include <tqvaluelist.h>
+#include <tqstringlist.h>
-class QDomElement;
-class QDomDocument;
-class QVariant;
+class TQDomElement;
+class TQDomDocument;
+class TQVariant;
namespace KexiDB {
@@ -81,38 +81,38 @@ class KEXI_DB_EXPORT LookupFieldSchema
void setType(Type type) { m_type = type; }
/*! @return row source type name. @see setTypeByName() */
- QString typeName() const;
+ TQString typeName() const;
/*! Sets row source type by name using \a typeName. Accepted (cast sensitive)
names are "table", "query", "sql", "valuelist", "fieldlist".
For other value NoType type is set. */
- void setTypeByName( const QString& typeName );
+ void setTypeByName( const TQString& typeName );
/*! @return a string for row source: table name, query name or anonymous query
provided as KEXISQL string. If rowSourceType() is a ValueList,
rowSourceValues() should be used instead. If rowSourceType() is a FieldList,
rowSource() should return table or query name. */
- QString name() const { return m_name; }
+ TQString name() const { return m_name; }
/*! Sets row source value. @see value() */
- void setName(const QString& name);
+ void setName(const TQString& name);
/*! @return row source values specified if type() is ValueList. */
- QStringList values() const;
+ TQStringList values() const;
/*! Sets row source values used if type() is ValueList.
Using it clears name (see name()). */
- void setValues(const QStringList& values);
+ void setValues(const TQStringList& values);
/*! \return String for debugging purposes. */
- QString debugString() const;
+ TQString debugString() const;
/*! Shows debug information. */
void debug() const;
private:
Type m_type;
- QString m_name;
- QStringList *m_values;
+ TQString m_name;
+ TQStringList *m_values;
};
LookupFieldSchema();
@@ -136,11 +136,11 @@ class KEXI_DB_EXPORT LookupFieldSchema
/*! @return a list of visible column: a list of integers specifying a column that has
to be visible in the combo box (counted from 0).
Empty list means unspecified value. */
- QValueList<uint> visibleColumns() const { return m_visibleColumns; }
+ TQValueList<uint> visibleColumns() const { return m_visibleColumns; }
/*! Sets a list of visible columns to \a list.
Columns will be separated with a single space character when displayed. */
- void setVisibleColumns(const QValueList<uint>& list) { m_visibleColumns = list; }
+ void setVisibleColumns(const TQValueList<uint>& list) { m_visibleColumns = list; }
/*! A helper method.
If visibleColumns() contains one item, this item is returned (a typical case).
@@ -157,10 +157,10 @@ class KEXI_DB_EXPORT LookupFieldSchema
/*! @return a number of ordered integers specifying column widths;
-1 means 'default width' for a given column. */
- const QValueList<int> columnWidths() const { return m_columnWidths; }
+ const TQValueList<int> columnWidths() const { return m_columnWidths; }
/*! Sets column widths. @see columnWidths */
- void setColumnWidths(const QValueList<int>& widths) { m_columnWidths = widths; }
+ void setColumnWidths(const TQValueList<int>& widths) { m_columnWidths = widths; }
/*! @return true if column headers are visible in the associated
combo box popup or the list view. The default is false. */
@@ -202,7 +202,7 @@ class KEXI_DB_EXPORT LookupFieldSchema
void setDisplayWidget(DisplayWidget widget) { m_displayWidget = widget; }
/*! \return String for debugging purposes. */
- QString debugString() const;
+ TQString debugString() const;
/*! Shows debug information. */
void debug() const;
@@ -210,21 +210,21 @@ class KEXI_DB_EXPORT LookupFieldSchema
/*! Loads data of lookup column schema from DOM tree.
The data can be outdated or invalid, so the app should handle such cases.
@return a new LookupFieldSchema object even if lookupEl contains no valid contents. */
- static LookupFieldSchema* loadFromDom(const QDomElement& lookupEl);
+ static LookupFieldSchema* loadFromDom(const TQDomElement& lookupEl);
- /*! Saves data of lookup column schema to \a parentEl DOM element of \a doc document. */
- static void saveToDom(LookupFieldSchema& lookupSchema, QDomDocument& doc, QDomElement& parentEl);
+ /*! Saves data of lookup column schema to \a tqparentEl DOM element of \a doc document. */
+ static void saveToDom(LookupFieldSchema& lookupSchema, TQDomDocument& doc, TQDomElement& tqparentEl);
/*! Sets property of name \a propertyName and value \a value for the lookup schema \a lookup
\return true on successful set and false on failure because of invalid value or invalid property name. */
static bool setProperty(
- LookupFieldSchema& lookup, const QCString& propertyName, const QVariant& value );
+ LookupFieldSchema& lookup, const TQCString& propertyName, const TQVariant& value );
protected:
RowSource m_rowSource;
int m_boundColumn;
- QValueList<uint> m_visibleColumns;
- QValueList<int> m_columnWidths;
+ TQValueList<uint> m_visibleColumns;
+ TQValueList<int> m_columnWidths;
uint m_maximumListRows;
DisplayWidget m_displayWidget;
bool m_columnHeadersVisible : 1;